/******************** (C) COPYRIGHT 2005 STMicroelectronics ********************
* File Name          : 91x_DENET.h
* Author             : MCD Application Team
* Date First Issued  : 21/10/2005 :  V1.0
* Description        : This file contains all the functions prototypes for the
*                      Dma dedicated to the MAC Ethernet ,software library.
**********************************************************************************
* History:
* 11/11/2005 :  V1.0
**********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS WITH
* CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
* OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT
* OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION
* CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*********************************************************************************/

/* Define to prevent recursive inclusion ------------------------------------ */
#ifndef __91x_DENET_H
#define __91x_DENET_H

/* Includes ------------------------------------------------------------------*/
#include "91x_map.h"
#include "91x_type.h"

/* Exported types ------------------------------------------------------------*/
/* DENET descriptor structure type define */
typedef struct
{
  u32 DENET_Addr;
  u32 DENET_NextAddr;
  FunctionalState  WrapEn;
  FunctionalState  NpolEn;
  FunctionalState  FixAddr;
}DENET_Descriptor;


/* DENET Init structure type define */
typedef struct
{
  u8  DENET_TrDirection;
  u8  DENET_TxBurstSize;
  u8  DENET_RxBurstSize;
  u8  DENET_EntryTrig;
  u16 DENET_DfetchDly;
  u16 DENET_AddrWrap;
  u16 DENET_TimeOut;
  DENET_Descriptor DENET_TrDescriptor;
  FunctionalState  DENET_LoopBackEn;
  FunctionalState  DENET_DelayEn;
  FunctionalState  DENET_NxtEn;
  FunctionalState  DENET_ContEn;
}DENET_InitTypeDef ;

/* Exported constants --------------------------------------------------------*/
/* Transfer direction */
#define DENET_RX             0x10
#define DENET_TX	            0x30

/* DENET Transfer Burst Size */
#define DENET_Incr16   0x0
#define DENET_Incr8    0x1
#define DENET_Incr4    0x2
#define DENET_Single   0x3


/* DENET Interrupt sources */
#define DENET_INT_TX_CURR_DONE	0x32
#define DENET_INT_MAC8023	0x28
#define DENET_INT_TX_MERR	0x25
#define DENET_INT_TX_DONE	0x23
#define DENET_INT_TX_NEXT	0x22
#define DENET_INT_TX_TO	        0x19
#define DENET_INT_TX_ENTRY	0x18
#define DENET_INT_TX_FULL	0x17
#define DENET_INT_TX_EMPTY	0x16
#define DENET_INT_RX_CURR_DONE	0x15
#define DENET_INT_RX_MERR	0x09
#define DENET_INT_RX_DONE	0x07
#define DENET_INT_NEXT	        0x06
#define DENET_INT_PACKET_LOST	0x05
#define DENET_INT_RX_TO	        0x03
#define DENET_INT_RX_ENTRY	0x02
#define DENET_INT_RX_FULL	0x01
#define DENET_RX_EMPTY	        0x00

/* DENET Flags */
#define DENET_FLAG_RxDelay	0x2C03
#define DENET_FLAG_RxEntry	0x2C02
#define DENET_FLAG_RxFifoFull	0x2C01
#define DENET_FLAG_RxFifoEmpty	0x2C00
#define DENET_FLAG_TxDelay	0x4C03
#define DENET_FLAG_TxEntry	0x4C02
#define DENET_FLAG_TxFifoFull	0x4C01
#define DENET_FLAG_TxFifoEmpty	0x4C00
#define DENET_FLAG_CollisionSeen 0x1007
#define DENET_FLAG_RuntFrame     0x1006
#define DENET_FLAG_FilterFail	0x1005
#define DENET_FLAG_UnderRun	0x3005

/* DENET_INTEN   */

#define DENET_INTEN_RX_EMPTY_EN         0x00000001
#define DENET_INTEN_RX_FULL_EN          0x00000002
#define DENET_INTEN_RX_ENTRY_EN         0x00000004
#define DENET_INTEN_RX_TO_EN            0x00000008

#define DENET_INTEN_PLOST_EN            0x00000020	/* packet lost */
#define DENET_INTEN_RX_NEXT_EN          0x00000040
#define DENET_INTEN_RX_DONE_EN          0x00000080
#define DENET_INTEN_RX_MERR_EN          0x00000200
#define DENET_INTEN_RX_CURRDONE_EN      0x00008000

#define DENET_INTEN_TX_EMPTY_EN         0x00010000
#define DENET_INTEN_TX_FULL_EN          0x00020000
#define DENET_INTEN_TX_ENTRY_EN         0x00040000
#define DENET_INTEN_TX_TO_EN            0x00080000

#define DENET_INTEN_TX_NEXT_EN          0x00400000
#define DENET_INTEN_TX_DONE_EN          0x00800000
#define DENET_INTEN_TX_MERR_EN          0x02000000
#define DENET_INTEN_TX_CURRDONE_EN      0x80000000

/* DENET_INTSTAT   */

/* DENET_INTSTAT   */

#define DENET_INTSTAT_RXEMPTY_MASK        (0x00000001)
#define DENET_INTSTAT_RXFULL_MASK         (0x00000002)
#define DENET_INTSTAT_PLOST_MASK          (0x00000020)
#define DENET_INTSTAT_RXNEXT_MASK         (0x00000040)
#define DENET_INTSTAT_RXDONE_MASK         (0x00000080)
#define DENET_INTSTAT_RXMERR_MASK         (0x00000200)
#define DENET_INTSTAT_RXCURRDONE_MASK     (0x00008000)
#define DENET_INTSTAT_TXEMPTY_MASK        (0x00010000)
#define DENET_INTSTAT_TXFULL_MASK         (0x00020000)
#define DENET_INTSTAT_TXNEXT_MASK         (0x00400000)
#define DENET_INTSTAT_TXDONE_MASK         (0x00800000)
#define DENET_INTSTAT_TXMERR_MASK         (0x02000000)
#define DENET_INTSTAT_TXCURRDONE_MASK     (0x80000000)


#define DENET_INTSTAT_RX_EMPTY_EN         DENET_INTEN_RX_EMPTY_EN
#define DENET_INTSTAT_RX_FULL_EN          DENET_INTEN_RX_FULL_EN
#define DENET_INTSTAT_RX_ENTRY_EN         DENET_INTEN_RX_ENTRY_EN
#define DENET_INTSTAT_RX_TO_EN            DENET_INTEN_RX_TO_EN
#define DENET_INTSTAT_PLOST_EN            DENET_INTEN_PLOST_EN
#define DENET_INTSTAT_RX_NEXT_EN          DENET_INTEN_RX_NEXT_EN
#define DENET_INTSTAT_RX_DONE_EN          DENET_INTEN_RX_DONE_EN
#define DENET_INTSTAT_RX_MERR_EN          DENET_INTEN_RX_MERR_EN
#define DENET_INTSTAT_RX_CURRDONE_EN      DENET_INTEN_RX_CURRDONE_EN

#define DENET_INTSTAT_TX_EMPTY_EN         DENET_INTEN_TX_EMPTY_EN
#define DENET_INTSTAT_TX_FULL_EN          DENET_INTEN_TX_FULL_EN
#define DENET_INTSTAT_TX_ENTRY_EN         DENET_INTEN_TX_ENTRY_EN
#define DENET_INTSTAT_TX_TO_EN            DENET_INTEN_TX_TO_EN
#define DENET_INTSTAT_TX_NEXT_EN          DENET_INTEN_TX_NEXT_EN
#define DENET_INTSTAT_TX_DONE_EN          DENET_INTEN_TX_DONE_EN
#define DENET_INTSTAT_TX_MERR_EN          DENET_INTEN_TX_MERR_EN
#define DENET_INTSTAT_TX_CURRDONE_EN      DENET_INTEN_TX_CURRDONE_EN

#define DENET_INTSTAT_RX_ERROR_MASK (DENET_INTSTAT_RX_FULL_EN | \
                                   DENET_INTSTAT_PLOST_EN   | \
                                   DENET_INTSTAT_RX_NEXT_EN | \
                                   DENET_INTSTAT_RX_MERR_EN)

#define DENET_INTSTAT_RX_MASK	(DENET_INTSTAT_RX_EMPTY_EN    | \
                                 DENET_INTSTAT_RX_FULL_EN     | \
                                 DENET_INTSTAT_PLOST_EN       | \
                                 DENET_INTSTAT_RX_NEXT_EN     | \
                                 DENET_INTSTAT_RX_DONE_EN     | \
                                 DENET_INTSTAT_RX_MERR_EN     | \
                                 DENET_INTSTAT_RX_CURRDONE_EN)

#define DENET_INTSTAT_TX_ERROR_MASK (DENET_INTSTAT_TX_FULL_EN | \
                                   DENET_INTSTAT_TX_NEXT_EN | \
                                   DENET_INTSTAT_TX_MERR_EN)

#define DENET_INTSTAT_TX_MASK	(DENET_INTSTAT_TX_EMPTY_EN   | \
                                 DENET_INTSTAT_TX_FULL_EN    | \
                                 DENET_INTSTAT_TX_NEXT_EN    | \
                                 DENET_INTSTAT_TX_DONE_EN    | \
                                 DENET_INTSTAT_TX_MERR_EN    | \
                                 DENET_INTSTAT_TX_CURRDONE_EN)

#define DMA_RX_START_DFETCH_DLY_MASK   0x00FFFF00
#define DMA_RX_START_DFETCH_DEFAULT    0x00010000
#define DMA_TX_START_DFETCH_DLY_MASK   0x00FFFF00
#define DMA_TX_START_DFETCH_DEFAULT    0x00010000
#define DMA_TX_START_URUN            0x00000020
#define DMA_TX_START_URUN_MASK         0x00000020


/* Exported constants --------------------------------------------------------*/
/* Module private variables --------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

void DENET_Init(DENET_InitTypeDef* DENET_InitStruct);
void DENET_DeInit(void);
void DENET_StructInit(DENET_InitTypeDef* DENET_InitStruct);
u16  DENET_GetDMACurrentCount(u8 bDirection);
u32  DENET_GetCurrentDmaAddr(u8 bDirection);
void DENET_Cmd (u8 bDirection);
u8 DENET_GetDmaEntries(u8 bDirection);
u8 DENET_GetDmaPointer(u8 bDirection);
u8 DENET_GetIOPointer(u8 bDirection);
void DENET_SoftResetCmd(FunctionalState NewState);
u8 DENET_GetTxRxDataConfig(u8 bField);
void DENET_ITConfig(u8 DENET_IT, FunctionalState NewState);
ITStatus DENET_GetITSatus(u8 DENET_IT);
FlagStatus DENET_GetFlagSatus(u16 DENET_FLAG);

#endif /* __91x_DENET_H */

/******************* (C) COPYRIGHT 2005 STMicroelectronics *****END OF FILE****/

