/*************************************************************************
 *
 *    Used with ICCARM and AARM.
 *
 *    (c) Copyright IAR Systems 2005
 *
 *    File name   : main.c
 *    Description : Define main module
 *
 *    History :
 *    1. Data        : June 24, 2005
 *       Author      : Stanimir Bonev
 *       Description : Create
 *    2. Data        : Nov 1, 2005
 *       Author      : Stanimir Bonev
 *       Description : modify (new revision of the board)
 *
 * Jumpers:
 *  EXT/JLINK - depend of power source
 *  M0.L/M0.H - 2-3
 *  M1.L/M1.H - 2-3
 *  R-T       - Absence
 *
 * Terminal setings
 *  Baud rate = 9600
 *  Data bits = 8
 *  Parity    = no
 *  Stop bits = 1
 *  Flow control = no
 *
 *    $Revision: 1.1 $
 *
**************************************************************************/

#include "includes.h"

// UART0 Send char
void Uart0SendChar (Int8U c)
{
  UART_SendData(UART0, c);
  while(UART_GetFlagStatus(UART0, UART_FLAG_TxFIFOFull) != RESET);
}

// UART1 Send char
void Uart1SendChar (Int8U c)
{
  UART_SendData(UART1, c);
  while(UART_GetFlagStatus(UART1, UART_FLAG_TxFIFOFull) != RESET);
}

// UART2 Send char
void Uart2SendChar (Int8U c)
{
  UART_SendData(UART2, c);
  while(UART_GetFlagStatus(UART2, UART_FLAG_TxFIFOFull) != RESET);
}

// UART0 receive char
Int8U Uart0ReceiveChar (void)
{
Int8U Data;
  while(UART_GetFlagStatus(UART0, UART_FLAG_RxFIFOEmpty) == SET);
  Data = UART0->DR;
  return(Data);
}

// UART1 receive char
Int8U Uart1ReceiveChar (void)
{
Int8U Data;
  while(UART_GetFlagStatus(UART1, UART_FLAG_RxFIFOEmpty) == SET);
  Data = UART1->DR;
  return(Data);
}

// UART2 receive char
Int8U Uart2ReceiveChar (void)
{
Int8U Data;
  while(UART_GetFlagStatus(UART2, UART_FLAG_RxFIFOEmpty) == SET);
  Data = UART2->DR;
  return(Data);
}

// UART0 receive char test
Int8U Uart0ReceiveCharTest (void)
{
  return(UART_GetFlagStatus(UART0, UART_FLAG_RxFIFOEmpty) != SET);
}

// UART1 receive char
Int8U Uart1ReceiveCharTest (void)
{
  return(UART_GetFlagStatus(UART1, UART_FLAG_RxFIFOEmpty) != SET);
}

// UART2 receive char
Int8U Uart2ReceiveCharTest (void)
{
  return(UART_GetFlagStatus(UART2, UART_FLAG_RxFIFOEmpty) != SET);
}

// Get ch
int getchar(void)
{
  return(Uart0ReceiveChar());
}

// Send char
int putchar (int c)
{
  Uart0SendChar(c);
  return(c);
}
// kbdhit
Boolean kbdhit(void)
{
  return(Uart0ReceiveCharTest());
}

/*************************************************************************
 * Function Name: main
 * Parameters: none
 *
 * Return: none
 *
 * Description: main
 *
 *************************************************************************/
int main()
{
UART_InitTypeDef UART_InitStructure;
GPIO_InitTypeDef GPIO_InitStructure;
Int32U Baud = 9600;

  SCU_MCLKSourceConfig(SCU_MCLK_OSC);

  FMI_Config(FMI_READ_WAIT_STATE_2,FMI_WRITE_WAIT_STATE_0, FMI_PWD_ENABLE,\
             FMI_LVD_ENABLE,FMI_FREQ_HIGH);

  SCU_HCLKDivisorConfig(SCU_HCLK_Div1);
  SCU_PCLKDivisorConfig(SCU_PCLK_Div2);
  SCU_PLLFactorsConfig(N,M,P);              /* PLL = 96 MHz */
  SCU_PLLCmd(ENABLE);                       /* PLL Enabled  */
  SCU_MCLKSourceConfig(SCU_MCLK_PLL);       /* MCLK = PLL   */

  SCU->EMPTY2[0] = 0;
  SCU->EMPTY2[1] = 0;

  SCU_APBPeriphClockConfig(__GPIO3, ENABLE);
  GPIO_DeInit(GPIO3);
  SCU_APBPeriphClockConfig(__GPIO4, ENABLE);
  GPIO_DeInit(GPIO5);
  SCU_APBPeriphClockConfig(__GPIO6, ENABLE);

  SCU_APBPeriphClockConfig(__UART0, ENABLE);
  UART_DeInit(UART0);
  SCU_APBPeriphClockConfig(__UART1, ENABLE);
  UART_DeInit(UART1);
  SCU_APBPeriphClockConfig(__UART2, ENABLE);
  UART_DeInit(UART2);

  UART_Cmd(UART0, DISABLE);
  UART_Cmd(UART1, DISABLE);
  UART_Cmd(UART2, DISABLE);

  /* Gonfigure P4.0*/
  GPIO_ANAPinConfig(GPIO_ANAChannelALL,ENABLE);

  /*Gonfigure UART0_Rx pin GPIO5.1*/
  GPIO_InitStructure.GPIO_Direction = GPIO_PinInput;
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_1;
  GPIO_InitStructure.GPIO_Type = GPIO_Type_PushPull ;
  GPIO_InitStructure.GPIO_IPConnected = GPIO_IPConnected_Enable;
  GPIO_InitStructure.GPIO_Alternate = GPIO_InputAlt1  ;
  GPIO_Init (GPIO5, &GPIO_InitStructure);

  /*Gonfigure UART0_Tx pin GPIO3.4*/
  GPIO_InitStructure.GPIO_Direction = GPIO_PinOutput;
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4;
  GPIO_InitStructure.GPIO_Type = GPIO_Type_PushPull ;
  GPIO_InitStructure.GPIO_Alternate = GPIO_OutputAlt3  ;
  GPIO_Init (GPIO3, &GPIO_InitStructure);

  UART_StructInit(&UART_InitStructure);
  UART_InitStructure.UART_WordLength = UART_WordLength_8D;
  UART_InitStructure.UART_StopBits = UART_StopBits_1;
  UART_InitStructure.UART_Parity = UART_Parity_No ;
  UART_InitStructure.UART_BaudRate = 115200;
  UART_InitStructure.UART_HardwareFlowControl = UART_HardwareFlowControl_None;
  UART_InitStructure.UART_Mode = UART_Mode_Tx_Rx;
  UART_InitStructure.UART_FIFO = UART_FIFO_Disable;

  UART_Init(UART0, &UART_InitStructure);

  /* Enable the UART0 */
  UART_Cmd(UART0, ENABLE);

  /*Gonfigure UART1_Rx pin GPIO3.2*/
  GPIO_InitStructure.GPIO_Direction = GPIO_PinInput;
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_2;
  GPIO_InitStructure.GPIO_Type = GPIO_Type_PushPull ;
  GPIO_InitStructure.GPIO_Alternate = GPIO_InputAlt1  ;
  GPIO_InitStructure.GPIO_IPConnected = GPIO_IPConnected_Enable;
  GPIO_Init (GPIO3, &GPIO_InitStructure);

  /*Gonfigure UART1_Tx pin GPIO3.3*/
  GPIO_InitStructure.GPIO_Direction = GPIO_PinOutput;
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_3;
  GPIO_InitStructure.GPIO_Type = GPIO_Type_PushPull ;
  GPIO_InitStructure.GPIO_Alternate = GPIO_OutputAlt2  ;
  GPIO_Init (GPIO3, &GPIO_InitStructure);

  // init
  UART_Cmd(UART1, DISABLE);
  UART_StructInit(&UART_InitStructure);
  UART_InitStructure.UART_WordLength = UART_WordLength_8D;
  UART_InitStructure.UART_StopBits = UART_StopBits_1;
  UART_InitStructure.UART_Parity = UART_Parity_No ;
  UART_InitStructure.UART_BaudRate = Baud;
  UART_InitStructure.UART_HardwareFlowControl = UART_HardwareFlowControl_None;
  UART_InitStructure.UART_Mode = UART_Mode_Tx_Rx;
  UART_InitStructure.UART_FIFO = UART_FIFO_Disable;
  UART_Init(UART1, &UART_InitStructure);
  UART_IrDACmd(IrDA1,ENABLE);
  SCU_UARTIrDASelect(UART1,SCU_UARTMode_IrDA);
  UART_IrDASetCounter(IrDA1,18000000);
  UART_IrDACmd(IrDA1,ENABLE);
  UART_Cmd(UART1, ENABLE);

  while(1)
  {
    if(Uart1ReceiveCharTest())
    {
      Uart1SendChar(Uart1ReceiveChar());
//      Uart1SendChar(0x55/*Uart1ReceiveChar()*/);
    }
  }
}
